@@ -1,30 +1,57 @@
-from .superpowered import (
+from .auth import (
     set_api_key,
-    get_total_storage,
+    set_base_url,
+)
+
+from .knowledge_bases import (
     create_knowledge_base,
     update_knowledge_base,
     list_knowledge_bases,
     get_knowledge_base,
     delete_knowledge_base,
+)
+
+from .documents import (
     create_document_via_text,
     create_document_via_url,
     create_document_via_file,
+    update_file,
     download_file,
     list_documents,
     get_document,
     update_document,
     delete_document,
+)
+
+from .query import (
     query,
     query_knowledge_bases,
-    query_passages,
-    set_base_url,
+)
+
+from .chat import (
+    create_chat_thread,
+    list_chat_threads,
+    get_chat_thread,
+    update_chat_thread,
+    delete_chat_thread,
+    get_chat_response,
+    list_thread_interactions,
+)
+
+from .usage import (
+    get_total_storage,
+    get_billable_events,
+    get_api_logs,
 )
 
 from . import exceptions
 
 __all__ = [
     'set_api_key',
+    'set_base_url',
     'get_total_storage',
+    'get_billable_events',
+    'get_api_logs',
     'create_knowledge_base',
     'update_knowledge_base',
     'list_knowledge_bases',
@@ -33,6 +60,7 @@ __all__ = [
     'create_document_via_text',
     'create_document_via_url',
     'create_document_via_file',
+    'update_file',
     'download_file',
     'list_documents',
     'get_document',
@@ -40,7 +68,12 @@ __all__ = [
     'delete_document',
     'query',
     'query_knowledge_bases',
-    'query_passages',
-    'set_base_url',
+    'create_chat_thread',
+    'list_chat_threads',
+    'get_chat_thread',
+    'update_chat_thread',
+    'delete_chat_thread',
+    'get_chat_response',
+    'list_thread_interactions',
     'exceptions',
 ]
\ No newline at end of file
